# CLogger
My way python logger configuration

CLogger contains two classes (CustomLogger and CustomFormatter)
based on default logging library. CustomoLogger class
initialize and configure logging library the way I like.